@@ -100,6 +100,8 @@ __all__ = [
     "Channel",
     "ChannelException",
     "DSSKey",
+    "ECDSAKey",
+    "Ed25519Key",
     "HostKeys",
     "Message",
     "MissingHostKeyPolicy",
